"""The iCloudPy library."""
import logging

from icloudpy.base import ICloudPyService  # pylint: disable=unused-import

logging.getLogger(__name__).addHandler(logging.NullHandler())
